
public class IngredientLine {

	/**
	 * The ingredient used for this ingredient line.
	 */
	private Ingredient ingredient;
	/**
	 * The quantity of the given ingredient.
	 */
	private double quantity;
	/**
	 * The units used to measure the quantity of the given ingredient.
	 */
	private Unit unit;

	/**
	 * Constructor for an IngredientLine object.
	 * 
	 * @param ingredient The ingredient used.
	 * @param quantity The quantity of that ingredient.
	 * @param unit The unit of that ingredient.
	 */
	public IngredientLine(Ingredient ingredient, double quantity, Unit unit) {
		this.ingredient = ingredient;
		this.quantity = quantity;
		this.unit = unit;
	}

	/**
	 * Getter for the ingredient attribute.
	 * @return Returns the Ingredient enum associated with this object.
	 */
	public Ingredient getIngredient() {
		return ingredient;
	}

	/**
	 * Returns all information contained in this IngredientLine object in the following format:
	 * 
	 * <quantity> <ingredient name> <unit>
	 * 
	 * Unit will be singular for a quantity of 1, plural otherwise.
	 * 
	 * @return Returns all information contained in this IngredientLine object in a sensible format.
	 */
	public String getIngredientLine() {
		String ingredientLine = "" + quantity;

		if (!unit.getName().equals("")) {
			ingredientLine += " " + unit.getName();
			if (quantity != 1 && !unit.getName().equals("")) {
				ingredientLine += "s";
			}
		}

		ingredientLine += " " + ingredient.getName();

		return ingredientLine;
	}
}
